@@ -2,6 +2,7 @@ from plover.engine import StenoEngine
 from plover_application_controls import WindowTracker
 
 from plover_per_application_state import PerApplicationStateExtension
+from plover_per_application_state.transition.handler import DynamicTitleTransitionHandler
 
 
 def command(engine: StenoEngine, arg: str) -> None:
@@ -26,8 +27,13 @@ def clear_window(engine: StenoEngine) -> None:
     engine.clear_translator_state()
 
 
+def prevent_merge(engine: StenoEngine) -> None:
+    DynamicTitleTransitionHandler.prevent_merge()
+
+
 _COMMAND_MAP = {
     "clear": clear,
     "clear_all": clear_all,
-    "clear_window": clear_window
+    "clear_window": clear_window,
+    "prevent_merge": prevent_merge
 }
